/* Generated by wayland-scanner 1.25.0 */

#ifndef TABLET_UNSTABLE_V1_ENUM_PROTOCOL_H
#define TABLET_UNSTABLE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef ZWP_TABLET_TOOL_V1_TYPE_ENUM
#define ZWP_TABLET_TOOL_V1_TYPE_ENUM
/**
 * @ingroup iface_zwp_tablet_tool_v1
 * a physical tool type
 *
 * Describes the physical type of a tool. The physical type of a tool
 * generally defines its base usage.
 *
 * The mouse tool represents a mouse-shaped tool that is not a relative
 * device but bound to the tablet's surface, providing absolute
 * coordinates.
 *
 * The lens tool is a mouse-shaped tool with an attached lens to
 * provide precision focus.
 */
enum zwp_tablet_tool_v1_type {
	/**
	 * Pen
	 */
	ZWP_TABLET_TOOL_V1_TYPE_PEN = 0x140,
	/**
	 * Eraser
	 */
	ZWP_TABLET_TOOL_V1_TYPE_ERASER = 0x141,
	/**
	 * Brush
	 */
	ZWP_TABLET_TOOL_V1_TYPE_BRUSH = 0x142,
	/**
	 * Pencil
	 */
	ZWP_TABLET_TOOL_V1_TYPE_PENCIL = 0x143,
	/**
	 * Airbrush
	 */
	ZWP_TABLET_TOOL_V1_TYPE_AIRBRUSH = 0x144,
	/**
	 * Finger
	 */
	ZWP_TABLET_TOOL_V1_TYPE_FINGER = 0x145,
	/**
	 * Mouse
	 */
	ZWP_TABLET_TOOL_V1_TYPE_MOUSE = 0x146,
	/**
	 * Lens
	 */
	ZWP_TABLET_TOOL_V1_TYPE_LENS = 0x147,
};
#endif /* ZWP_TABLET_TOOL_V1_TYPE_ENUM */

#ifndef ZWP_TABLET_TOOL_V1_CAPABILITY_ENUM
#define ZWP_TABLET_TOOL_V1_CAPABILITY_ENUM
/**
 * @ingroup iface_zwp_tablet_tool_v1
 * capability flags for a tool
 *
 * Describes extra capabilities on a tablet.
 *
 * Any tool must provide x and y values, extra axes are
 * device-specific.
 */
enum zwp_tablet_tool_v1_capability {
	/**
	 * Tilt axes
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_TILT = 1,
	/**
	 * Pressure axis
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_PRESSURE = 2,
	/**
	 * Distance axis
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_DISTANCE = 3,
	/**
	 * Z-rotation axis
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_ROTATION = 4,
	/**
	 * Slider axis
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_SLIDER = 5,
	/**
	 * Wheel axis
	 */
	ZWP_TABLET_TOOL_V1_CAPABILITY_WHEEL = 6,
};
#endif /* ZWP_TABLET_TOOL_V1_CAPABILITY_ENUM */

#ifndef ZWP_TABLET_TOOL_V1_BUTTON_STATE_ENUM
#define ZWP_TABLET_TOOL_V1_BUTTON_STATE_ENUM
/**
 * @ingroup iface_zwp_tablet_tool_v1
 * physical button state
 *
 * Describes the physical state of a button that produced the button event.
 */
enum zwp_tablet_tool_v1_button_state {
	/**
	 * button is not pressed
	 */
	ZWP_TABLET_TOOL_V1_BUTTON_STATE_RELEASED = 0,
	/**
	 * button is pressed
	 */
	ZWP_TABLET_TOOL_V1_BUTTON_STATE_PRESSED = 1,
};
#endif /* ZWP_TABLET_TOOL_V1_BUTTON_STATE_ENUM */

#ifndef ZWP_TABLET_TOOL_V1_ERROR_ENUM
#define ZWP_TABLET_TOOL_V1_ERROR_ENUM
enum zwp_tablet_tool_v1_error {
	/**
	 * given wl_surface has another role
	 */
	ZWP_TABLET_TOOL_V1_ERROR_ROLE = 0,
};
#endif /* ZWP_TABLET_TOOL_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
