/* Generated by wayland-scanner 1.25.0 */

#ifndef XDG_FOREIGN_UNSTABLE_V2_ENUM_PROTOCOL_H
#define XDG_FOREIGN_UNSTABLE_V2_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef ZXDG_EXPORTER_V2_ERROR_ENUM
#define ZXDG_EXPORTER_V2_ERROR_ENUM
/**
 * @ingroup iface_zxdg_exporter_v2
 * error values
 *
 * These errors can be emitted in response to invalid xdg_exporter
 * requests.
 */
enum zxdg_exporter_v2_error {
	/**
	 * surface is not an xdg_toplevel
	 */
	ZXDG_EXPORTER_V2_ERROR_INVALID_SURFACE = 0,
};
#endif /* ZXDG_EXPORTER_V2_ERROR_ENUM */

#ifndef ZXDG_IMPORTED_V2_ERROR_ENUM
#define ZXDG_IMPORTED_V2_ERROR_ENUM
/**
 * @ingroup iface_zxdg_imported_v2
 * error values
 *
 * These errors can be emitted in response to invalid xdg_imported
 * requests.
 */
enum zxdg_imported_v2_error {
	/**
	 * surface is not an xdg_toplevel
	 */
	ZXDG_IMPORTED_V2_ERROR_INVALID_SURFACE = 0,
};
#endif /* ZXDG_IMPORTED_V2_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
